@@ -9,7 +9,6 @@ import java.io.FileInputStream;
 import java.util.Properties;
 
 /**
- *
  * @author ludo
  */
 public class POMCleanerTest extends TestBase {
@@ -17,6 +16,17 @@ public class POMCleanerTest extends TestBase {
     private File pomProperties;
     private File specialDependencies;
 
+    private POMCleaner instance;
+
+    public void setUp() {
+        super.setUp();
+        instance = new POMCleaner();
+        instance.getRules().setRulesFile(null);
+        instance.getIgnoreRules().setRulesFile(null);
+        instance.getPublishedRules().setRulesFile(null);
+    }
+
+
     public void tearDown() {
         super.tearDown();
         if (specialDependencies != null && specialDependencies.exists()) {
@@ -36,7 +46,6 @@ public class POMCleanerTest extends TestBase {
         pomProperties = new File(testDir, "pom.properties");
         usePom("maven.xml");
         boolean noParent = true;
-        POMCleaner instance = new POMCleaner();
         instance.addDefaultRules();
         instance.addRule(new DependencyRule("org.codehaus.plexus plexus-container-default jar s/1\\.0-alpha-.*/1.0-alpha/"));
         instance.cleanPom(pom, updatedPom, pomProperties, noParent, false, null, "maven2");
@@ -57,7 +66,6 @@ public class POMCleanerTest extends TestBase {
         pomProperties = new File(testDir, "pom.properties");
         usePom("modello-core.xml");
         boolean noParent = false;
-        POMCleaner instance = new POMCleaner();
         instance.addDefaultRules();
         instance.cleanPom(pom, updatedPom, pomProperties, noParent, false, null, "libmodello-java");
         assertXMLEqual(read("modello-core.cleaned"), read(updatedPom));
@@ -88,7 +96,6 @@ public class POMCleanerTest extends TestBase {
         pomProperties = new File(testDir, "pom.properties");
         usePom("wagon-http-lightweight.xml");
         boolean noParent = false;
-        POMCleaner instance = new POMCleaner();
         instance.addDefaultRules();
         instance.cleanPom(pom, updatedPom, pomProperties, noParent, false, null, "libwagon-java");
         assertXMLEqual(read("wagon-http-lightweight.cleaned"), read(updatedPom));
@@ -108,7 +115,6 @@ public class POMCleanerTest extends TestBase {
         pomProperties = new File(testDir, "pom.properties");
         usePom("plexus-container-default.xml");
         boolean noParent = true;
-        POMCleaner instance = new POMCleaner();
         instance.addDefaultRules();
         instance.addRule(new DependencyRule("org.codehaus.plexus plexus-container-default jar s/1\\.0-alpha-.*/1.0-alpha/"));
         instance.cleanPom(pom, updatedPom, pomProperties, noParent, false, null, "libplexus-container-default-java");
@@ -129,7 +135,6 @@ public class POMCleanerTest extends TestBase {
         pomProperties = new File(testDir, "pom.properties");
         usePom("plexus-active-collections.pom");
         boolean noParent = true;
-        POMCleaner instance = new POMCleaner();
         instance.addDefaultRules();
         instance.addRule(new DependencyRule("junit junit jar s/3\\..*/3.x/"));
         instance.addRule(new DependencyRule("org.codehaus.plexus plexus-container-default jar s/1\\.0-alpha.*/1.0-alpha/"));
@@ -152,7 +157,6 @@ public class POMCleanerTest extends TestBase {
         pomProperties = new File(testDir, "pom.properties");
         usePom("plexus-archiver.pom");
         boolean noParent = true;
-        POMCleaner instance = new POMCleaner();
         instance.addDefaultRules();
         instance.cleanPom(pom, updatedPom, pomProperties, noParent, false, null, "libplexus-archiver-java");
         assertXMLEqual(read("plexus-archiver.cleaned"), read(updatedPom));
@@ -172,7 +176,6 @@ public class POMCleanerTest extends TestBase {
         pomProperties = new File(testDir, "pom.properties");
         usePom("slf4j.xml");
         boolean noParent = true;
-        POMCleaner instance = new POMCleaner();
         instance.addDefaultRules();
         instance.cleanPom(pom, updatedPom, pomProperties, noParent, false, null, "libslf4j-java");
         assertXMLEqual(read("slf4j.cleaned"), read(updatedPom));
@@ -192,7 +195,6 @@ public class POMCleanerTest extends TestBase {
         pomProperties = new File(testDir, "pom.properties");
         usePom("commons-validator.xml");
         boolean noParent = true;
-        POMCleaner instance = new POMCleaner();
         instance.addDefaultRules();
         instance.addRule(new DependencyRule("junit junit jar s/3\\..*/3.x/"));
         instance.cleanPom(pom, updatedPom, pomProperties, noParent, false, null, "libcommons-validator-java");
@@ -213,7 +215,6 @@ public class POMCleanerTest extends TestBase {
         pomProperties = new File(testDir, "pom.properties");
         usePom("servlet-api.pom");
         boolean noParent = true;
-        POMCleaner instance = new POMCleaner();
         instance.addDefaultRules();
         instance.addRule(new DependencyRule("s/org.apache.tomcat/javax.servlet/ servlet-api jar s/.*/2.5/"));
         instance.cleanPom(pom, updatedPom, pomProperties, noParent, false, null, "libservlet2.5-java");
@@ -227,6 +228,27 @@ public class POMCleanerTest extends TestBase {
         assertEquals("2.5", pomInfo.get("debianVersion"));
     }
 
+    /**
+     * Test of cleanPom method, of class POMCleaner.
+     */
+    public void testCleanHibernateValidatorParentPom() throws Exception {
+        pomProperties = new File(testDir, "pom.properties");
+        usePom("hibernate-validator-parent.pom");
+        boolean noParent = true;
+        instance.addDefaultRules();
+        instance.addIgnoreRule(new DependencyRule("org.apache.maven.wagon wagon-webdav jar *"));
+        instance.addIgnoreRule(new DependencyRule("org.jboss.maven.plugins maven-jdocbook-plugin maven-plugin *"));
+        instance.cleanPom(pom, updatedPom, pomProperties, noParent, false, null, "libhibernate-validator-java");
+        assertXMLEqual(read("hibernate-validator-parent.cleaned"), read(updatedPom));
+        Properties pomInfo = new Properties();
+        pomInfo.load(new FileInputStream(pomProperties));
+        assertEquals("org.hibernate", pomInfo.get("groupId"));
+        assertEquals("hibernate-validator-parent", pomInfo.get("artifactId"));
+        assertEquals("pom", pomInfo.get("type"));
+        assertEquals("4.0.2.GA", pomInfo.get("version"));
+        assertEquals("debian", pomInfo.get("debianVersion"));
+    }
+
     /**
      * Test of main method, of class DebianPOM.
      */
@@ -236,7 +258,7 @@ public class POMCleanerTest extends TestBase {
         usePom("maven.xml");
         useFile("maven.rules", specialDependencies);
         String[] args = {"--no-parent", "-pmaven2", "-r" + specialDependencies.getAbsolutePath(),
-            pom.getAbsolutePath(), updatedPom.getAbsolutePath(), pomProperties.getAbsolutePath() };
+                pom.getAbsolutePath(), updatedPom.getAbsolutePath(), pomProperties.getAbsolutePath()};
         POMCleaner.main(args);
         assertXMLEqual(read("maven.cleaned"), read(updatedPom));
     }
